# -*- coding: utf-8 -*-
#
# Sphinx configuration for aiida-crystal17
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

import os
import shutil
import subprocess
import sys
import time

import aiida_crystal17

# -- General configuration ------------------------------------------------

# The master toctree document.
master_doc = "index"

# General information about the project.
project = u"aiida-crystal17"
copyright_first_year = "2018"
copyright_owners = "Chris Sewell"

current_year = str(time.localtime().tm_year)
copyright_year_string = (
    current_year
    if current_year == copyright_first_year
    else "{}-{}".format(copyright_first_year, current_year)
)
# pylint: disable=redefined-builtin
copyright = u"{}, {}. All rights reserved".format(
    copyright_year_string, copyright_owners
)

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The full version, including alpha/beta/rc tags.
release = aiida_crystal17.__version__
# The short X.Y version.
version = ".".join(release.split(".")[:2])

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "myst_nb",
    "sphinx.ext.autodoc",
    "sphinx.ext.mathjax",
    "sphinx.ext.intersphinx",
    "sphinx.ext.viewcode",
    "sphinx.ext.todo",
    "sphinx.ext.napoleon",
]

exclude_patterns = [
    "_build",
    "Thumbs.db",
    ".DS_Store",
    "**.ipynb_checkpoints",
]
jupyter_execute_notebooks = "off"
myst_admonition_enable = True
myst_deflist_enable = True
myst_url_schemes = ("http", "https", "mailto")
panels_add_boostrap_css = False
html_theme = "sphinx_book_theme"
html_theme_options = {
    "github_url": "https://github.com/aiidaplugins/aiida-crystal17",
    "repository_url": "https://github.com/aiidaplugins/aiida-crystal17",
    "repository_branch": "master",
    "use_edit_page_button": True,
    "path_to_docs": "docs/",
    # "expand_sections": ["use/index", "examples/index"],
}

intersphinx_mapping = {
    "python": ("https://docs.python.org/3.7", None),
    "jsonshema": ("https://python-jsonschema.readthedocs.io/en/stable/", None),
    "aiida": ("http://aiida-core.readthedocs.io/en/latest/", None),
    "aiida_quantumespresso": (
        "http://aiida-quantumespresso.readthedocs.io/en/latest/",
        None,
    ),
    "ase": ("https://wiki.fysik.dtu.dk/ase/", None),
    "spglib": ("https://spglib.github.io/spglib/", None),
}

intersphinx_aliases = {
    ("py:class", "file-like"): ("py:class", "io.TextIOWrapper"),
    ("py:class", "json.encoder.JSONEncoder"): ("py:class", "json.JSONEncoder"),
    ("py:class", "aiida.StructureData"): (
        "py:class",
        "aiida.orm.nodes.data.structure.StructureData",
    ),
    ("py:class", "aiida.orm.Dict"): ("py:class", "aiida.orm.nodes.data.dict.Dict"),
    ("py:class", "aiida.orm.ArrayData"): (
        "py:class",
        "aiida.orm.nodes.data.array.array.ArrayData",
    ),
    ("py:class", "callable"): ("py:class", "collections.abc.Callable"),
}

# If true, sectionauthor and moduleauthor directives will be shown in the
# output. They are ignored by default.
show_authors = True

# A list of ignored prefixes for module index sorting.
# modindex_common_prefix = []

# Napoleon Docstring settings
napoleon_numpy_docstring = True
napoleon_include_private_with_doc = False
napoleon_include_special_with_doc = True
napoleon_use_admonition_for_examples = False
napoleon_use_admonition_for_notes = False
napoleon_use_admonition_for_references = False
napoleon_use_ivar = True
napoleon_use_param = True
napoleon_use_rtype = True

# Warnings to ignore when using the -n (nitpicky) option
# We should ignore any python built-in exception, for instance
nitpick_ignore = [
    ("py:class", "filelike"),
]

# autodoc options, see
# http://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#configuration
autoclass_content = "both"


def run_apidoc(_):
    """Run sphinx-apidoc when building the documentation.

    Needs to be done in conf.py in order to include the APIdoc in the
    build on readthedocs.
    See also https://github.com/rtfd/readthedocs.org/issues/1139
    """
    source_dir = os.path.abspath(os.path.dirname(__file__))
    apidoc_dir = os.path.join(source_dir, "apidoc")
    if os.path.exists(apidoc_dir):
        shutil.rmtree(apidoc_dir)
    package_dir = os.path.join(source_dir, os.pardir, os.pardir, "aiida_crystal17")
    exclude_paths = [
        os.path.join(
            source_dir, os.pardir, os.pardir, "aiida_crystal17", "tests", "test_*"
        ),
        os.path.join(
            source_dir, os.pardir, os.pardir, "aiida_crystal17", "tests", "raw_files"
        ),
    ]

    # In #1139, they suggest the route below, but this ended up
    # calling sphinx-build, not sphinx-apidoc
    # from sphinx.apidoc import main
    # main([None, '-e', '-o', apidoc_dir, package_dir, '--force'])

    cmd_path = "sphinx-apidoc"
    if hasattr(sys, "real_prefix"):  # Check to see if we are in a virtualenv
        # If we are, assemble the path manually
        cmd_path = os.path.abspath(os.path.join(sys.prefix, "bin", "sphinx-apidoc"))

    options = [
        "--private",
        "--force",
        "--no-toc",
        "-o",
        apidoc_dir,
        package_dir,
    ]

    # See https://stackoverflow.com/a/30144019
    env = os.environ.copy()
    env["SPHINX_APIDOC_OPTIONS"] = "members,undoc-members,show-inheritance"
    subprocess.check_call([cmd_path] + options + exclude_paths, env=env)


def add_intersphinx_aliases_to_inv(app):
    """Add type aliases for intersphinx.

    see https://github.com/sphinx-doc/sphinx/issues/5603
    """
    from sphinx.ext.intersphinx import InventoryAdapter

    inventories = InventoryAdapter(app.builder.env)

    for alias, target in app.config.intersphinx_aliases.items():
        alias_domain, alias_name = alias
        target_domain, target_name = target
        try:
            found = inventories.main_inventory[target_domain][target_name]
            try:
                inventories.main_inventory[alias_domain][alias_name] = found
            except KeyError:
                continue
        except KeyError:
            continue


def run_reentry_scan(_):
    from reentry import manager

    manager.scan()


def setup(app):
    """Add functions to the Sphinx setup."""
    app.connect("builder-inited", run_reentry_scan)
    if os.environ.get("RUN_APIDOC", "").lower() != "false":
        app.connect("builder-inited", run_apidoc)
    app.add_config_value("intersphinx_aliases", {}, "env")
    app.connect("builder-inited", add_intersphinx_aliases_to_inv)


# -- Options for HTML output ----------------------------------------------

# Add any paths that contain custom themes here, relative to this directory.
# ~ html_theme_path = ["."]

# The name for this set of Sphinx documents.  If None, it defaults to
# "<project> v<release> documentation".
# html_title = None

# A shorter title for the navigation bar.  Default is the same as html_title.
# html_short_title = None

# The name of an image file (relative to this directory) to place at the top
# of the sidebar.
# html_logo = "images/.png"

# The name of an image file (within the static path) to use as favicon of the
# docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
# pixels large.
# html_favicon = "images/favicon.ico"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
# html_static_path = ['_static']

# Add any extra paths that contain custom files (such as robots.txt or
# .htaccess) here, relative to this directory. These files are copied
# directly to the root of the documentation.
# html_extra_path = []

# If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
# using the given strftime format.
# html_last_updated_fmt = '%b %d, %Y'

# If true, SmartyPants will be used to convert quotes and dashes to
# typographically correct entities.
# html_use_smartypants = True

# Custom sidebar templates, maps document names to template names.
# html_sidebars = {}

# Additional templates that should be rendered to pages, maps page names to
# template names.
# html_additional_pages = {}

# If false, no module index is generated.
# html_domain_indices = True

# If false, no index is generated.
# html_use_index = True

# If true, the index is split into individual pages for each letter.
# html_split_index = False

# If true, links to the reST sources are added to the pages.
html_show_sourcelink = False

# If true, "Created using Sphinx" is shown in the HTML footer. Default is True.
# html_show_sphinx = True

# If true, "(C) Copyright ..." is shown in the HTML footer. Default is True.
# ~ html_show_copyright = False

# If true, an OpenSearch description file will be output, and all pages will
# contain a <link> tag referring to it.  The value of this option must be the
# base URL from which the finished HTML is served.
html_use_opensearch = "http://aiida-crystal17.readthedocs.io"

# This is the file name suffix for HTML files (e.g. ".xhtml").
# html_file_suffix = None

# Language to be used for generating the HTML full-text search index.
# Sphinx supports the following languages:
#   'da', 'de', 'en', 'es', 'fi', 'fr', 'hu', 'it', 'ja'
#   'nl', 'no', 'pt', 'ro', 'ru', 'sv', 'tr'
html_search_language = "en"

# Output file base name for HTML help builder.
htmlhelp_basename = "aiida-crystal17-doc"
